Contributing to django-timepiece
================================

django-timepiece is an open-source project and we welcome community
contributions. Please see our `contributing documentation
<http://django-timepiece.readthedocs.org/en/latest/contributing.html>`_ to
learn about our conventions and guidelines.
